pub fn validate_array<T, let N: u32>(array: [T; N]) -> u32 where T: Empty
Deprecated.
Routine which validates that all zero values of an array form a contiguous region at the end, i.e., of the form: [,,*...,0,0,0,0] where any * is non-zero. Note that a full array of non-zero values is valid.
Deprecated.
Routine which validates that all zero values of an array form a contiguous region at the end, i.e., of the form: [,,*...,0,0,0,0] where any * is non-zero. Note that a full array of non-zero values is valid.